@@ -91,11 +91,17 @@ class AutorunType(Protocol, Generic[State]):
         self: AutorunType,
         selector: Callable[[State], SelectorOutput],
         comparator: Callable[[State], Any] | None = None,
-    ) -> AutorunDecorator[State, SelectorOutput]:
+        *,
+        default_value: AutorunOriginalReturnType | None = None,
+        initial_run: bool = True,
+    ) -> AutorunDecorator[State, SelectorOutput, AutorunOriginalReturnType]:
         ...
 
 
-class AutorunDecorator(Protocol, Generic[State, SelectorOutput]):
+class AutorunDecorator(
+    Protocol,
+    Generic[State, SelectorOutput, AutorunOriginalReturnType],
+):
     def __call__(
         self: AutorunDecorator,
         func: Callable[[SelectorOutput], AutorunOriginalReturnType]
@@ -115,6 +121,8 @@ class AutorunReturnType(Protocol, Generic[AutorunOriginalReturnType]):
     def subscribe(
         self: AutorunReturnType,
         callback: Callable[[AutorunOriginalReturnType], Any],
+        *,
+        immediate: bool = False,
     ) -> Callable[[], None]:
         ...
 
